@@ -172,7 +172,7 @@ Kolf::LandscapeConfig::LandscapeConfig(Kolf::LandscapeItem* item, QWidget* paren
 
 void Kolf::LandscapeConfig::setBlinkInterval(int sliderValue)
 {
-	emit blinkIntervalChanged(100 - sliderValue);
+	Q_EMIT blinkIntervalChanged(100 - sliderValue);
 }
 
 //END Kolf::LandscapeConfig
@@ -537,7 +537,7 @@ bool Kolf::Slope::terrainCollisions() const
 QList<QGraphicsItem*> Kolf::Slope::infoItems() const
 {
 	QList<QGraphicsItem*> result;
-	foreach (ArrowItem* arrow, m_arrows)
+	for (ArrowItem* arrow : m_arrows)
 		result << arrow;
 	result << m_gradeItem;
 	return result;
@@ -564,11 +564,7 @@ Kolf::SlopeConfig::SlopeConfig(Kolf::Slope* slope, QWidget* parent)
 	KComboBox* typeBox = new KComboBox(this);
 	typeBox->addItems(g_slopeData->translatedGradientKeys);
 	typeBox->setCurrentIndex(slope->slopeType());
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 	connect(typeBox, QOverload<int>::of(&KComboBox::currentIndexChanged), slope, &Kolf::Slope::setSlopeType);
-#else
-	connect(typeBox, QOverload<int, const QString &>::of(&KComboBox::currentIndexChanged), slope, &Kolf::Slope::setSlopeType);
-#endif
 	layout->addWidget(typeBox, 0, 0, 1, 2);
 
 	QCheckBox* reversed = new QCheckBox(i18n("Reverse direction"), this);
