@@ -86,7 +86,7 @@ NewGameDialog::NewGameDialog(bool enableCourses)
 	}
 
 	enableButtons();
-	KPageWidgetItem *pageItem =0L;
+	KPageWidgetItem *pageItem =nullptr;
 	if (enableCourses)
 	{
 		coursePage = new QFrame();
@@ -105,10 +105,10 @@ NewGameDialog::NewGameDialog(bool enableCourses)
 		/// course loading
 		QStringList files;
 		const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::AppDataLocation, QStringLiteral("courses"), QStandardPaths::LocateDirectory);
-		Q_FOREACH (const QString& dir, dirs) {
+		for (const QString& dir : dirs) {
 			const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*"), QDir::Files);
-			Q_FOREACH (const QString& file, fileNames) {
-				files.append(dir + '/' + file);
+			for (const QString& file : fileNames) {
+				files.append(dir + QLatin1Char('/') + file);
 			}
 		}
 		const QStringList items = externCourses + files;
@@ -216,7 +216,7 @@ void NewGameDialog::slotOk()
 
 	config->deleteGroup("New Game Dialog");
 
-	PlayerEditor *curEditor = 0;
+	PlayerEditor *curEditor = nullptr;
 	int i = 0;
 	for (; i < editors.count(); ++i) {
 		curEditor = editors.at(i);
@@ -307,7 +307,7 @@ void NewGameDialog::addCourse()
 	if (hasDuplicates)
 		KMessageBox::information(this, i18n("Chosen course is already on course list."));
 
-	courseList->setCurrentItem(0);
+	courseList->setCurrentItem(nullptr);
 	courseSelected(0);
 	selectionChanged();
 }
@@ -367,7 +367,7 @@ PlayerEditor::PlayerEditor(const QString &startName, QColor startColor, QWidget
 
 void PlayerEditor::removeMe()
 {
-	emit deleteEditor(this);
+	Q_EMIT deleteEditor(this);
 }
 
 
